-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("Aloft")
local SML = AceLibrary("SharedMedia-1.0")
local SML_font = SML:List("font")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

Aloft.OnMenuRequest = 
{
	handler = Aloft,
	type = 'group',
	args = 
	{
		name =
		{
			type = 'group',
			name = L["Name"],
			desc = L["Nameplate text options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show unit names"],
					get = function() return Aloft.db.profile.nameplateText.visible end,
					set = function(v) Aloft.db.profile.nameplateText.visible = v Aloft:UpdateNameplateText() end
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the nameplate text"],
					max = 20,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.nameplateText.fontSize end,
					set = function(value) Aloft.db.profile.nameplateText.fontSize = value Aloft:UpdateNameplateText() end
				},
				alignment =
				{
					type = 'text',
					name = L["Alignment"],
					desc = L["Sets the alignment of the nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.alignment end,
					set = function(value) Aloft.db.profile.nameplateText.alignment = value Aloft:UpdateNameplateText() end,
					validate = {"LEFT", "CENTER", "RIGHT" },
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font outline for nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.outline end,
					set = function(value) Aloft.db.profile.nameplateText.outline = value Aloft:UpdateNameplateText() end,
					validate = {"None", "Normal", "Thick" },
				},
				overrideColors =
				{
					type = 'toggle',
					name = L["Override Colors"],
					desc = L["Override the games colors for nameplate text"],
					get = function() return Aloft.db.profile.nameplateText.overrideColors end,
					set = function(value) Aloft.db.profile.nameplateText.overrideColors = value Aloft:UpdateNameplateText() end,
				},
				colors =
				{
					type = 'group',
					name = L["Colors"],
					desc = L["Customize colors"],
					disabled = function() return not Aloft.db.profile.nameplateText.overrideColors end,
					args =
					{
						friendlyPlayer =
						{
							type = 'color',
							name = L["Friendly Players"],
							desc = L["Sets the nameplate color for friendly players"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyPlayer) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.friendlyPlayer = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						friendlyNPC =
						{
							type = 'color',
							name = L["Friendly NPCs"],
							desc = L["Sets the nameplate bar color for friendly NPCs"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyNPC) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.friendlyNPC = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						friendlyBoss =
						{
							type = 'color',
							name = L["Friendly Boss"],
							desc = L["Sets the nameplate color for friendly NPC Bosses"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.friendlyBoss) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.friendlyBoss = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						hostile =
						{
							type = 'color',
							name = L["Hostile Units"],
							desc = L["Sets the nameplate color for hostile units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.hostile) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.hostile = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						hostileBoss =
						{
							type = 'color',
							name = L["Hostile Boss"],
							desc = L["Sets the nameplate color for hostile boss units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.hostileBoss) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.hostileBoss = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						neutral =
						{
							type = 'color',
							name = L["Neutral Units"],
							desc = L["Sets the nameplate color for neutral units"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.neutral) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.neutral = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
						partyPet =
						{
							type = 'color',
							name = L["Party Pets"],
							desc = L["Sets the nameplate color for party pets"],
							get = function() return unpack(Aloft.db.profile.nameplateText.colors.partyPet) end,
							set = function(r, g, b, a) Aloft.db.profile.nameplateText.colors.partyPet = { r, g, b, a } Aloft:UpdateNameplateText() end,
							hasAlpha = true
						},
					}
				}
			},
		},

		healthBar =
		{
			type = 'group',
			name = L["Health Bar"],
			desc = L["Health Bar options"],
			args =
			{
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the health bar texture"],
					get = function() return Aloft.db.profile.healthBar.texture end,
					set = function(v) Aloft.db.profile.healthBar.texture = v Aloft:UpdateHealthBars() end,
					validate = SML_statusbar,
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the health bar alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.healthBar.alpha end,
					set = function(v) Aloft.db.profile.healthBar.alpha = v Aloft:UpdateHealthBars() end
				},
				colorByClass =
				{
					type = 'toggle',
					name = L["Color by Class"],
					desc = L["Sets the health bar color according to class. Requires Prat.PlayerNames enabled to show out of group colors"],
					get = function() return Aloft.db.profile.healthBar.colorByClass end,
					set = function(v) Aloft.db.profile.healthBar.colorByClass = v Aloft:UpdateHealthBars() end
				},
				groupOnly =
				{
					type = 'toggle',
					name = L["Group Only"],
					desc = L["Only colors group member's health bars by class"],
					disabled = function() return not Aloft.db.profile.healthBar.colorByClass end,
					get = function() return Aloft.db.profile.healthBar.groupOnly end,
					set = function(v) Aloft.db.profile.healthBar.groupOnly = v Aloft:UpdateHealthBars() end
				},
				colors =
				{
					type = 'group',
					name = L["Colors"],
					desc = L["Customize colors"],
					args =
					{
						friendlyPlayer =
						{
							type = 'color',
							name = L["Friendly Players"],
							desc = L["Sets the health bar color for friendly players"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyPlayer) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyPlayer = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyNPC =
						{
							type = 'color',
							name = L["Friendly NPCs"],
							desc = L["Sets the health bar color for friendly NPCs"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyNPC) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyNPC = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyBoss =
						{
							type = 'color',
							name = L["Friendly Boss"],
							desc = L["Sets the health bar color for friendly NPC Bosses"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostile =
						{
							type = 'color',
							name = L["Hostile Units"],
							desc = L["Sets the health bar color for hostile units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostile) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostile = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostileBoss =
						{
							type = 'color',
							name = L["Hostile Boss"],
							desc = L["Sets the health bar color for hostile boss units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostileBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostileBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						neutral =
						{
							type = 'color',
							name = L["Neutral Units"],
							desc = L["Sets the health bar color for neutral units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.neutral) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.neutral = { r, g, b } Aloft:UpdateHealthBars() end
						},
						partyPet =
						{
							type = 'color',
							name = L["Party Pets"],
							desc = L["Sets the health bar color for party pets"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.partyPet) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.partyPet = { r, g, b } Aloft:UpdateHealthBars() end
						},
					}
				}
			},
		},

		healthText =
		{
			type = 'group',
			name = L["Health Text"],
			desc = L["Health text options"],
			args =
			{
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the health text"],
					max = 20,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.healthText.fontSize end,
					set = function(value) Aloft.db.profile.healthText.fontSize = value Aloft:UpdateHealthTexts() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the outline for health text"],
					get = function() return Aloft.db.profile.healthText.outline end,
					set = function(value) Aloft.db.profile.healthText.outline = value Aloft:UpdateHealthTexts() end,
					validate = {"None", "Normal", "Thick"},
				},
				mode =
				{
					type = 'text',
					name = L["Mode"],
					desc = L["Choose what to show for health text"],
					get = function() return Aloft.db.profile.healthText.mode end,
					set = function(value) Aloft.db.profile.healthText.mode = value Aloft:UpdateHealthTexts() end,
					validate = {"Hidden", "Percent", "Group Health", "Group Health Deficit", "Health"},
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the health text"],
					get = function() return Aloft.db.profile.healthText.point end,
					set = function(v) Aloft.db.profile.healthText.point = v Aloft:UpdateHealthTexts() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the health text"],
					get = function() return Aloft.db.profile.healthText.relativeToPoint end,
					set = function(v) Aloft.db.profile.healthText.relativeToPoint = v Aloft:UpdateHealthTexts() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the health text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.healthText.offsetX end,
					set = function(v) Aloft.db.profile.healthText.offsetX = v Aloft:UpdateHealthTexts() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the health text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.healthText.offsetY end,
					set = function(v) Aloft.db.profile.healthText.offsetY = v Aloft:UpdateHealthTexts() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the alpha of the health text"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.healthText.alpha end,
					set = function(v) Aloft.db.profile.healthText.alpha = v Aloft:UpdateHealthTexts() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the health text color"],
					get = function() return unpack(Aloft.db.profile.healthText.color) end,
					set = function(r, g, b, a) Aloft.db.profile.healthText.color = { r, g, b, a } Aloft:UpdateHealthTexts() end,
				},
			},
		},

		levelText =
		{
			type = 'group',
			name = L["Level Text"],
			desc = L["Level text options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable level text display on the nameplate"],
					get = function() return Aloft.db.profile.levelText.visible end,
					set = function(v) Aloft.db.profile.levelText.visible = v Aloft:UpdateLevelText() end
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the level text"],
					max = 20,
					min = 5,
					step = 1,
					get = function() return Aloft.db.profile.levelText.fontSize end,
					set = function(value) Aloft.db.profile.levelText.fontSize = value Aloft:UpdateLevelText() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the font height of the level text"],
					get = function() return Aloft.db.profile.levelText.outline end,
					set = function(value) Aloft.db.profile.levelText.outline = value Aloft:UpdateLevelText() end,
					validate = {"None", "Normal", "Thick" },
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the level text"],
					get = function() return Aloft.db.profile.levelText.point end,
					set = function(v) Aloft.db.profile.levelText.point = v Aloft:UpdateLevelText() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the level text"],
					get = function() return Aloft.db.profile.levelText.relativeToPoint end,
					set = function(v) Aloft.db.profile.levelText.relativeToPoint = v Aloft:UpdateLevelText() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the level text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.levelText.offsetX end,
					set = function(v) Aloft.db.profile.levelText.offsetX = v Aloft:UpdateLevelText() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the level text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.levelText.offsetY end,
					set = function(v) Aloft.db.profile.levelText.offsetY = v Aloft:UpdateLevelText() end
				},
			},
		},

		overlay =
		{
			type = 'group',
			name = L["Overlay"],
			desc = L["Overlay options"],
			args =
			{
				visible =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show an overlay on the full health bar"],
					get = function() return Aloft.db.profile.overlay.visible end,
					set = function(v) Aloft.db.profile.overlay.visible = v Aloft:UpdateOverlays() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the overlay color"],
					disabled  = function() return not Aloft.db.profile.overlay.visible end,
					get = function() return unpack(Aloft.db.profile.overlay.color) end,
					set = function(r, g, b, a) Aloft.db.profile.overlay.color = { r, g, b, a } Aloft:UpdateOverlays() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the overlay texture"],
					get = function() return Aloft.db.profile.overlay.texture end,
					set = function(v) Aloft.db.profile.overlay.texture = v Aloft:UpdateOverlays() end,
					validate = SML_statusbar,
				},
			},
		},
	
		highlight =
		{
			type = 'group',
			name = L["Highlight"],
			desc = L["Mouseover highlight options"],
			args =
			{
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the highlight color"],
					get = function() return unpack(Aloft.db.profile.highlight.color) end,
					set = function(r, g, b, a) Aloft.db.profile.highlight.color = { r, g, b, a } Aloft:UpdateHighlights() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the highlight texture"],
					get = function() return Aloft.db.profile.highlight.texture end,
					set = function(v) Aloft.db.profile.highlight.texture = v Aloft:UpdateHighlights() end,
					validate = SML_statusbar,
				},
				mode =
				{
					type = "text",
					name = L["Blend Mode"],
					desc = L["Sets the blend mode for the highlight texture"],
					get = function() return Aloft.db.profile.highlight.blendMode end,
					set = function(v) Aloft.db.profile.highlight.blendMode = v Aloft:UpdateHighlights() end,
					validate = { "BLEND", "ADD" },
				},
			},
		},
	
		raidIcon =
		{
			type = 'group',
			name = L["Raid Icon"],
			desc = L["Raid icon placement options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable raid icon display on the nameplate"],
					get = function() return Aloft.db.profile.raidIcon.visible end,
					set = function(v) Aloft.db.profile.raidIcon.visible = v Aloft:UpdateRaidIcons() end
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the raid icon"],
					get = function() return Aloft.db.profile.raidIcon.point end,
					set = function(v) Aloft.db.profile.raidIcon.point = v Aloft:UpdateRaidIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the raid icon"],
					get = function() return Aloft.db.profile.raidIcon.relativeToPoint end,
					set = function(v) Aloft.db.profile.raidIcon.relativeToPoint = v Aloft:UpdateRaidIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				size =
				{
					type = 'range',
					name = L["Size"],
					desc = L["Size in pixels of the raid icon"],
					min = 4,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.size end,
					set = function(v) Aloft.db.profile.raidIcon.size = v Aloft:UpdateRaidIcons() end
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the raid icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.offsetX end,
					set = function(v) Aloft.db.profile.raidIcon.offsetX = v Aloft:UpdateRaidIcons() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the raid icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.raidIcon.offsetY end,
					set = function(v) Aloft.db.profile.raidIcon.offsetY = v Aloft:UpdateRaidIcons() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the raid icon alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.raidIcon.alpha end,
					set = function(v) Aloft.db.profile.raidIcon.alpha = v Aloft:UpdateRaidIcons() end
				},
			},
		},

		bossIcon =
		{
			type = 'group',
			name = L["Boss Icon"],
			desc = L["Boss icon placement options"],
			args =
			{
				visible = 
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Enable boss icon display on the nameplate"],
					get = function() return Aloft.db.profile.bossIcon.visible end,
					set = function(v) Aloft.db.profile.bossIcon.visible = v Aloft:UpdateBossIcons() end
				},
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the boss icon"],
					get = function() return Aloft.db.profile.bossIcon.point end,
					set = function(v) Aloft.db.profile.bossIcon.point = v Aloft:UpdateBossIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the boss icon"],
					get = function() return Aloft.db.profile.bossIcon.relativeToPoint end,
					set = function(v) Aloft.db.profile.bossIcon.relativeToPoint = v Aloft:UpdateBossIcons() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				size =
				{
					type = 'range',
					name = L["Size"],
					desc = L["Size in pixels of the boss icon"],
					min = 4,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.size end,
					set = function(v) Aloft.db.profile.bossIcon.size = v Aloft:UpdateBossIcons() end
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the boss icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.offsetX end,
					set = function(v) Aloft.db.profile.bossIcon.offsetX = v Aloft:UpdateBossIcons() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the boss icon"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.bossIcon.offsetY end,
					set = function(v) Aloft.db.profile.bossIcon.offsetY = v Aloft:UpdateBossIcons() end
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the boss icon alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.bossIcon.alpha end,
					set = function(v) Aloft.db.profile.bossIcon.alpha = v Aloft:UpdateBossIcons() end
				},
			},
		},
	},
}

Aloft:RegisterChatCommand({"/aloft"}, Aloft.OnMenuRequest)

-----------------------------------------------------------------------------
